@@ -2,7 +2,7 @@ import re,os,time
 import openai
 import json
 from collections import Counter
-from TTSandNLTK import get_keywords_in_phrase, generate_audio_text
+from langlearnai.TTSandNLTK import get_keywords_in_phrase, generate_audio_text
 import pycountry
 def get_lang_abbreaviation(language_name):
     try:
